@@ -2,7 +2,6 @@ package zonkafeedback
 
 import (
 	"context"
-	"fmt"
 	"net/http"
 	"regexp"
 	"strings"
@@ -52,7 +51,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			if err != nil {
 				continue
 			}
-			req.Header.Add("Z-API-TOKEN", fmt.Sprintf("%s", resMatch))
+			req.Header.Add("Z-API-TOKEN", resMatch)
 			res, err := client.Do(req)
 			if err == nil {
 				defer res.Body.Close()
